Module false_sharing

Module false_sharing 

Functions

find_sharing_conflicts
Return all groups of fields that share a cache line. Any cache line with two or more fields is a potential false-sharing hazard.
has_false_sharing
Return true if any cache line contains two or more Concurrent fields with different lock guards — a confirmed false-sharing hazard.
normalize_guard
Normalise a guard name for comparison.