Module impact
padlock_
core
0.10.0
Module impact
Module Items
Structs
Functions
In padlock_
core::
analysis
padlock_core
::
analysis
Module
impact
Structs

Impact
Estimate
Estimated impact of a struct layout inefficiency at various scales.
Functions

estimate_
impact
Compute the impact estimate for a struct layout inefficiency.