Module locality

Module locality 

Structs

FieldLocality

Functions

classify_fields
Classify every field as hot or cold.
has_locality_issue
Returns true if hot and cold fields are interleaved (a locality problem). If all fields are hot or all are cold the layout is fine.
partition_hot_cold
Split fields into (hot_names, cold_names) preserving original order.