Module arch

Module arch 

Structs

ArchConfig

Enums

Endianness

Constants

AARCH64
AARCH64_APPLE
AVR
AVR 8-bit (ATmega328P, ATmega2560, etc.) — no cache, 2-byte pointers.
CORTEX_M
ARM Cortex-M0 / M0+ / M3 — no cache.
CORTEX_M4
ARM Cortex-M4 / M4F / M7 / M33 — 32-byte cache lines.
RISCV64
WASM32
X86_64_SYSV

Functions

arch_by_name
Resolve an architecture name string or Rust target triple to a static ArchConfig.
arch_by_triple
Map a Rust target triple to an ArchConfig.
with_overrides
Create a custom ArchConfig by overriding specific fields of a base arch.