pub struct SkippedStruct {
pub name: String,
pub reason: String,
pub source_file: Option<String>,
}Expand description
A struct/type that was skipped during analysis because its layout cannot be accurately determined from source alone (e.g. generic/template types).
Fields
name: Stringreason: Stringsource_file: Option<String>Trait Implementations
Sourceimpl Clone for SkippedStruct
impl Clone for SkippedStruct
Sourcefn clone(&self) -> SkippedStruct
fn clone(&self) -> SkippedStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SkippedStruct
impl Debug for SkippedStruct
Sourceimpl<'de> Deserialize<'de> for SkippedStruct
impl<'de> Deserialize<'de> for SkippedStruct
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more