pub struct Report {
pub structs: Vec<StructReport>,
pub total_structs: usize,
pub total_wasted_bytes: usize,
pub analyzed_paths: Vec<String>,
}Fields
structs: Vec<StructReport>total_structs: usizetotal_wasted_bytes: usizeanalyzed_paths: Vec<String>Paths that were analyzed to produce this report (populated by the CLI).
Implementations
Sourceimpl Report
impl Report
Sourcepub fn from_layouts(layouts: &[StructLayout]) -> Report
pub fn from_layouts(layouts: &[StructLayout]) -> Report
Run all analysis passes over layouts and assemble the full report.